@@ -6,9 +6,9 @@ Type annotations for imagebuilder service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_imagebuilder.literals import ComponentFormatType
+    from mypy_boto3_imagebuilder.literals import BuildTypeType
 
-    data: ComponentFormatType = "SHELL"
+    data: BuildTypeType = "IMPORT"
     ```
 """
 import sys
@@ -20,11 +20,13 @@ else:
 
 
 __all__ = (
+    "BuildTypeType",
     "ComponentFormatType",
     "ComponentStatusType",
     "ComponentTypeType",
     "ContainerRepositoryServiceType",
     "ContainerTypeType",
+    "DiskImageFormatType",
     "EbsVolumeTypeType",
     "ImageStatusType",
     "ImageTypeType",
@@ -36,11 +38,13 @@ __all__ = (
 )
 
 
+BuildTypeType = Literal["IMPORT", "SCHEDULED", "USER_INITIATED"]
 ComponentFormatType = Literal["SHELL"]
 ComponentStatusType = Literal["DEPRECATED"]
 ComponentTypeType = Literal["BUILD", "TEST"]
 ContainerRepositoryServiceType = Literal["ECR"]
 ContainerTypeType = Literal["DOCKER"]
+DiskImageFormatType = Literal["RAW", "VHD", "VMDK"]
 EbsVolumeTypeType = Literal["gp2", "gp3", "io1", "io2", "sc1", "st1", "standard"]
 ImageStatusType = Literal[
     "AVAILABLE",
@@ -71,6 +75,7 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
@@ -90,6 +95,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -166,6 +172,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -192,6 +199,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -205,6 +213,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -250,6 +259,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -280,6 +290,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -295,6 +306,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -352,5 +364,6 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
